<?php
namespace Concrete\Package\OhLove;

use Concrete\Core\Package\Package;
use BlockType;
use PageTheme;
use PageTemplate;
use Concrete\Core\Block\BlockController;
use Concrete\Core\Page\Theme\Theme;
use FileImporter;
use Concrete\Core\Entity\File\Image\Thumbnail\Type\Type as ThumbnailType;

defined('C5_EXECUTE') or die(_("Access Denied."));
if (!function_exists('compat_is_version_8')) {
    function compat_is_version_8() {
        return interface_exists('\Concrete\Core\Export\ExportableInterface');
    }
}

class Controller extends Package
{

    protected $pkgHandle = 'oh_love'; //package handle
    protected $appVersionRequired = '5.7.5.6'; //concrete5's ver.
    protected $pkgVersion = '1.0.0'; //package's ver.
    protected $pkgAllowsFullContentSwap = true; //over ride

    public function getPackageDescription()
    {
        return t("This theme is a blog type web site.Style customization is also added and the style of three patterns can be changed.And responsive support.It is developing by 7.5.6 and corresponds to v8.");
    }

    public function getPackageName()
    {
        return t("oh_love");
    }
    
    public function import_files() 
    {
        // now we add in any files that this package has
        if (is_dir($this->getPackagePath() . '/content_files'))
         {
    
            $fh = new FileImporter();
            Core::make('helper/file')->getDirectoryContents($this->getPackagePath() . '/content_files');
    
            foreach ($contents as $filename) 
            {
                $f = $fh->import($this->getPackagePath() . '/content_files/' . $filename, $filename);
            }
        }
    }
    
    public function install()
    {
        $pkg = parent::install();
        $this->pageTemplates($pkg);
        PageTheme::add('oh_love', $pkg);

        if ( compat_is_version_8() ) {
            //code for version 8
            $this->installThumbnailV8();
        }
        else {
            //code for version 7
            $this->installThumbnailV57();
        }
    }
    
    private function installThumbnailV8(){
        $em = \ORM::entityManager();
        $share_thumbnail_pickup = $em->getRepository('\Concrete\Core\Entity\File\Image\Thumbnail\Type\Type')
                    ->findOneBy(['ftTypeHandle' => 'share_thumbnail_pickup']);
        if (!is_object($share_thumbnail_pickup)) {
            $type = new ThumbnailType();
            $type->setName('share thumbnail pickup');
            $type->setHandle('share_thumbnail_pickup');
            $type->setWidth(100);
            $type->setHeight(100);
            $type->save();
        }
        $share_thumbnail_related = $em->getRepository('\Concrete\Core\Entity\File\Image\Thumbnail\Type\Type')
                    ->findOneBy(['ftTypeHandle' => 'share_thumbnail_related']);
        if (!is_object($share_thumbnail_related)) {
            $type = new ThumbnailType();
            $type->setName('share thumbnail related');
            $type->setHandle('share_thumbnail_related');
            $type->setWidth(200);
            $type->setHeight(200);
            $type->save();
        }
        $share_thumbnail_square = $em->getRepository('\Concrete\Core\Entity\File\Image\Thumbnail\Type\Type')
                    ->findOneBy(['ftTypeHandle' => 'share_thumbnail_square']);
        if (!is_object($share_thumbnail_square)) {
            $type = new ThumbnailType();
            $type->setName('share thumbnail square');
            $type->setHandle('share_thumbnail_square');
            $type->setWidth(210);
            $type->setHeight(116);
            $type->save();
        }
        $share_thumbnail_height = $em->getRepository('\Concrete\Core\Entity\File\Image\Thumbnail\Type\Type')
                    ->findOneBy(['ftTypeHandle' => 'share_thumbnail_height']);
        if (!is_object($share_thumbnail_height)) {
            $type = new ThumbnailType();
            $type->setName('share thumbnail height');
            $type->setHandle('share_thumbnail_height');
            $type->setWidth(210);
            $type->setHeight(371);
            $type->save();
        }
        $share_thumbnail_width = $em->getRepository('\Concrete\Core\Entity\File\Image\Thumbnail\Type\Type')
                    ->findOneBy(['ftTypeHandle' => 'share_thumbnail_width']);
        if (!is_object($share_thumbnail_width)) {
            $type = new ThumbnailType();
            $type->setName('share thumbnail width');
            $type->setHandle('share_thumbnail_width');
            $type->setWidth(488);
            $type->setHeight(274);
            $type->save();
        }
        $small = $em->getRepository('\Concrete\Core\Entity\File\Image\Thumbnail\Type\Type')
                    ->findOneBy(['ftTypeHandle' => 'small']);
        if (!is_object($small)) {
            $type = new ThumbnailType();
            $type->setName('Small');
            $type->setHandle('small');
            $type->setWidth(740);
            $type->save();
        }
        $medium = $em->getRepository('\Concrete\Core\Entity\File\Image\Thumbnail\Type\Type')
                     ->findOneBy(['ftTypeHandle' => 'medium']);
        if (!is_object($medium)) {
            $type = new ThumbnailType();
            $type->setName('Medium');
            $type->setHandle('medium');
            $type->setWidth(940);
            $type->save();
        }
        $large = $em->getRepository('\Concrete\Core\Entity\File\Image\Thumbnail\Type\Type')
                    ->findOneBy(['ftTypeHandle' => 'large']);
        if (!is_object($large)) {
            $type = new ThumbnailType();
            $type->setName('Large');
            $type->setHandle('large');
            $type->setWidth(1140);
            $type->save();
        }
    }
    private function installThumbnailV57(){
        $share_thumbnail_pickup = \Concrete\Core\File\Image\Thumbnail\Type\Type::getByHandle('share_thumbnail_pickup');
        if (!is_object($share_thumbnail_pickup)) {
            $type = new \Concrete\Core\File\Image\Thumbnail\Type\Type();
            $type->setName('share thumbnail pickup');
            $type->setHandle('share_thumbnail_pickup');
            $type->setWidth(100);
            $type->setHeight(100);
            $type->save();
        }
        $share_thumbnail_related = \Concrete\Core\File\Image\Thumbnail\Type\Type::getByHandle('share_thumbnail_related');
        if (!is_object($share_thumbnail_related)) {
            $type = new \Concrete\Core\File\Image\Thumbnail\Type\Type();
            $type->setName('share thumbnail related');
            $type->setHandle('share_thumbnail_related');
            $type->setWidth(200);
            $type->setHeight(200);
            $type->save();
        }
        $share_thumbnail_square = \Concrete\Core\File\Image\Thumbnail\Type\Type::getByHandle('share_thumbnail_square');
        if (!is_object($share_thumbnail_square)) {
            $type = new \Concrete\Core\File\Image\Thumbnail\Type\Type();
            $type->setName('share thumbnail square');
            $type->setHandle('share_thumbnail_square');
            $type->setWidth(210);
            $type->setHeight(116);
            $type->save();
        }
        $share_thumbnail_height = \Concrete\Core\File\Image\Thumbnail\Type\Type::getByHandle('share_thumbnail_height');
        if (!is_object($share_thumbnail_height)) {
            $type = new \Concrete\Core\File\Image\Thumbnail\Type\Type();
            $type->setName('share thumbnail height');
            $type->setHandle('share_thumbnail_height');
            $type->setWidth(210);
            $type->setHeight(371);
            $type->save();
        }
        $share_thumbnail_width = \Concrete\Core\File\Image\Thumbnail\Type\Type::getByHandle('share_thumbnail_width');
        if (!is_object($share_thumbnail_height)) {
            $type = new \Concrete\Core\File\Image\Thumbnail\Type\Type();
            $type->setName('share thumbnail width');
            $type->setHandle('share_thumbnail_width');
            $type->setWidth(488);
            $type->setHeight(274);
            $type->save();
        }
        $small = \Concrete\Core\File\Image\Thumbnail\Type\Type::getByHandle('small');
        if (!is_object($small)) {
            $type = new \Concrete\Core\File\Image\Thumbnail\Type\Type();
            $type->setName('Small');
            $type->setHandle('small');
            $type->setWidth(740);
            $type->save();
        }
        $medium = \Concrete\Core\File\Image\Thumbnail\Type\Type::getByHandle('medium');
        if (!is_object($medium)) {
            $type = new \Concrete\Core\File\Image\Thumbnail\Type\Type();
            $type->setName('Medium');
            $type->setHandle('medium');
            $type->setWidth(940);
            $type->save();
        }
        $large = \Concrete\Core\File\Image\Thumbnail\Type\Type::getByHandle('large');
        if (!is_object($large)) {
            $type = new \Concrete\Core\File\Image\Thumbnail\Type\Type();
            $type->setName('Large');
            $type->setHandle('large');
            $type->setWidth(1140);
            $type->save();
        }
    }
    
    private function pageTemplates($pkg) {
        if (!PageTemplate::getByHandle('home')) {
            PageTemplate::add('home', t('Home'), 'full.png', $pkg);
        }
        if (!PageTemplate::getByHandle('contact')) {
            PageTemplate::add('contact', t('Contact'), 'blank.png', $pkg);
        }
        if (!PageTemplate::getByHandle('default')) {
            PageTemplate::add('default', t('Default'), 'blank.png', $pkg);
        }
        if (!PageTemplate::getByHandle('detail')) {
            PageTemplate::add('detail', t('Detail'), 'blank.png', $pkg);
        }
        if (!PageTemplate::getByHandle('faq')) {
            PageTemplate::add('faq', t('Faq'), 'blank.png', $pkg);
        }
        if (!PageTemplate::getByHandle('information')) {
            PageTemplate::add('information', t('Information'), 'blank.png', $pkg);
        }
        if (!PageTemplate::getByHandle('full')) {
            PageTemplate::add('full', t('Full'), 'full.png', $pkg);
        }
    }

}